@@ -10,6 +10,7 @@ import urllib.parse
 from urllib.error import URLError, HTTPError
 import ssl
 
+from rkclient.auth import RK_USER_AUTH_HEADER
 from rkclient.entities import PEM, Artifact
 from rkclient.serialization import PEMSerialization, _encode_as_base64
 
@@ -50,7 +51,8 @@ class RKClient:
     def __init__(self, receiver_url: str,
                  emitter_id: Optional[UUID] = None,
                  timeout_sec: int = 5,
-                 insecure: bool = True):
+                 insecure: bool = True,
+                 user_auth: str = ''):
         """
 
         :param receiver_url:
@@ -63,7 +65,10 @@ class RKClient:
             emitter_id = uuid1()
         self.emitter_id = emitter_id
         self.timeout_sec = timeout_sec
+        self.user_auth = user_auth
         log.info(f"ver {RK_VERSION}, connecting to: {self.receiver_url}")
+        if self.user_auth:
+            log.info(f"Authorizing with {RK_USER_AUTH_HEADER} header")
         self.insecure = insecure
         if self.insecure:
             log.warning("Disabled SSL certificate check")
@@ -85,14 +90,14 @@ class RKClient:
         return RK_VERSION
 
     def prepare_pem(self,
-                    type: str,
+                    pem_type: str,
                     predecessor_id: Optional[UUID] = None,
                     properties: Optional[Dict] = None,
                     tag_name: str = 'latest',
                     tag_namespace: Optional[UUID] = None) -> PEM:
         """
         In memory creation of PEM
-        :param type: user defined type of event
+        :param pem_type: user defined type of event
         :param predecessor_id: pass None if this event doesn't have a predecessor
         :param properties:
         :param tag_name:
@@ -101,7 +106,7 @@ class RKClient:
         """
         uid = uuid1()
         now = datetime.datetime.utcfromtimestamp(time.time()).strftime('%Y-%m-%d %H:%M:%S')
-        pem = PEM(uid, type, predecessor_id, self.emitter_id, now)
+        pem = PEM(uid, pem_type, predecessor_id, self.emitter_id, now)
         if properties is not None:
             pem.Properties = properties
         pem.Tag = tag_name
@@ -112,19 +117,19 @@ class RKClient:
         return pem
 
     def prepare_artifact(self,
-                         type: str,
+                         artifact_type: str,
                          properties: Dict[str, str],
                          uid: Optional[UUID] = None) -> Artifact:
         """
         In memory creation of Artifact. It needs to be passed to PEM.add_uses/produces_artifact()
-        :param type:
+        :param artifact_type:
         :param properties:
         :param uid:
         :return: new Artifact
         """
         if uid is None:
             uid = uuid1()
-        art = Artifact(uid, type, properties)
+        art = Artifact(uid, artifact_type, properties)
         return art
 
     def send_pem(self, pem: PEM) -> Tuple[str, bool]:
@@ -187,12 +192,16 @@ class RKClient:
     def _get(self, url_postfix: str, query_params: Optional[Dict[str, Any]] = None) -> Tuple[str, bool]:
         url = self.receiver_url + url_postfix + self._encode_query_params(query_params)
         req = urllib.request.Request(url=url)
+        if self.user_auth:
+            req.add_header(RK_USER_AUTH_HEADER, self.user_auth)
         return self._make_request(req)
 
     def _post(self, url_postfix: str, payload: str, query_params: Optional[Dict[str, Any]] = None) -> Tuple[str, bool]:
         url = self.receiver_url + url_postfix + self._encode_query_params(query_params)
         req = urllib.request.Request(url=url, data=payload.encode())
         req.add_header('Content-Type', 'application/json')
+        if self.user_auth:
+            req.add_header(RK_USER_AUTH_HEADER, self.user_auth)
         return self._make_request(req)
 
     def _make_request(self, request):
