@@ -1,6 +1,9 @@
+import logging
 from uuid import UUID
 from typing import Dict, Optional, List
 
+log = logging.getLogger("rkclient")
+
 """
 PEM and Artifact
 
@@ -16,12 +19,12 @@ class Artifact:
 
     def __init__(self,
                  id: UUID,
-                 type: str,
+                 artifact_type: str,
                  properties: Dict[str, str],
                  solely_id: bool = False
                  ):
         self.ID = id
-        self.Type = type
+        self.Type = artifact_type
         self.Properties = properties
         self.CreatedAt = None
         self.TaxonomyFiles: Optional[Dict] = None
@@ -45,12 +48,12 @@ class PEM:
 
     def __init__(self,
                  id: UUID,
-                 type: str,
+                 pem_type: str,
                  predecessor_id: Optional[UUID],
                  emitter_id: UUID,
                  timestamp_client: str):
         self.ID = id
-        self.Type = type
+        self.Type = pem_type
         self.Predecessor = predecessor_id
         self.Emitter = emitter_id
         self.TimestampClient = timestamp_client  # UTC time in format YYYY-MM-DD HH:MM:SS
@@ -62,11 +65,19 @@ class PEM:
         self.Tag = ''
         self.TagNamespace = ''
 
-    def add_uses_artifact(self, art: Artifact):
-        self.UsesArtifacts.append(art)
+    def add_uses_artifact(self, artifact: Artifact):
+        """
+        Avoids adding to "uses artifacts" list already existing there artifact.
+        :param artifact: to add
+        """
+        for art in self.UsesArtifacts:
+            if art.ID == artifact.ID:
+                log.warning(f"Not adding \"uses artifact\" with ID {artifact.ID} to PEM {self.ID}, because one with such ID already exists in list.")
+                return
+        self.UsesArtifacts.append(artifact)
 
-    def add_produces_artifact(self, art: Artifact):
-        self.ProducesArtifacts.append(art)
+    def add_produces_artifact(self, artifact: Artifact):
+        self.ProducesArtifacts.append(artifact)
 
     def __str__(self):
         return f"PEM({self.ID.hex}, {self.Type}, {self.Predecessor}, {self.Properties}, {self.TimestampClient}, " \
