@@ -1,4 +1,6 @@
 import os
+import time
+import datetime
 import logging
 from uuid import UUID, uuid1
 from typing import Dict, Optional, Tuple
@@ -14,8 +16,9 @@ MOCK_ENV_VAR = "RK_MOCK"
 
 
 class RKClientMock(RKClient):
-    def __init__(self, receiver_url: str, emitter_id: Optional[UUID] = None, timeout_sec: int = 5): # noqa
+    def __init__(self, receiver_url: str, emitter_id: Optional[UUID] = None, timeout_sec: int = 5, user_auth: str = ''): # noqa
         log.info(f"ver {RK_VERSION} - using MOCK client")
+        self.emitter_id = emitter_id
 
     def __enter__(self):
         return self
@@ -24,18 +27,24 @@ class RKClientMock(RKClient):
         pass
 
     def prepare_pem(self,
-                    type: str,
+                    pem_type: str,
                     predecessor_id: Optional[UUID] = None,
                     properties: Optional[Dict] = None,
                     tag_name: str = 'latest',
                     tag_namespace: Optional[UUID] = None) -> PEM:
-        return PEM(uuid1(), 'mocked', None, uuid1(), '')
+        now = datetime.datetime.utcfromtimestamp(time.time()).strftime('%Y-%m-%d %H:%M:%S')
+        pem = PEM(uuid1(), pem_type, predecessor_id, uuid1(), now)
+        if properties is not None:
+            pem.Properties = properties
+        return pem
 
     def prepare_artifact(self,
-                         type: str,
+                         artifact_type: str,
                          properties: Dict[str, str],
                          uid: Optional[UUID] = None) -> Artifact:
-        return Artifact(uuid1(), 'mocked', {}, False)
+        if uid is None:
+            uid = uuid1()
+        return Artifact(uid, artifact_type, properties, False)
 
     def send_pem(self, pem: PEM) -> Tuple[str, bool]:
         log.debug("send pem - mocked")
@@ -47,7 +56,7 @@ class RKClientMock(RKClient):
 
     def get_info(self) -> Tuple[str, bool]:
         log.debug("get info - mocked")
-        return "{'postgres_enabled': true, 'neo4j_enabled': true, 'version':" + RK_VERSION + "} ", True
+        return "{'postgres_enabled': true, 'neo4j_enabled': true, 'pem_size_limit': 10000, 'version':" + RK_VERSION + "} ", True
 
     def get_tag(self, namespace: UUID, tag_name: str) -> Tuple[str, bool]:
         log.debug("get tag - mocked")
